@@ -1,4 +1,5 @@
-targets = {'FPT': ['FPT'],
+targets = {
+           'FPT': ['FPT'],
            'FVS': ['FVS'],
            'FOYD': ['FOYD'],
            'FOS': ['FOS'],
@@ -16,21 +17,21 @@ targets = {'FPT': ['FPT'],
            }
 
 exclude = {
-           'FPT': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FVS': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FOYD': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FOS': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FPTP': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FVSP': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FOYDP': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FYDR': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FUV': ['T_KCV', 'T_KCD', 'T_KCDV'],
-           'FDV': ['T_KCU', 'T_KCD', 'T_KCDV'],
-           'DWTT': ['T_KCU', 'T_KCV', 'T_KCDV'],
+           'FPT': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FVS': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FOYD': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FOS': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FPTP': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FVSP': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FOYDP': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FYDR': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FUV': ['T_KCV', 'T_KCD'],
+           'FDV': ['T_KCU', 'T_KCD'],
+           'DWTT': ['T_KCU', 'T_KCV'],
            'DVC': ['T_KCU', 'T_KCV', 'T_KCD'],
-           'NB_': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FPT05': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV'],
-           'FPTP05': ['T_KCU', 'T_KCV', 'T_KCD', 'T_KCDV']
+           'NB_': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FPT05': ['T_KCU', 'T_KCV', 'T_KCD'],
+           'FPTP05': ['T_KCU', 'T_KCV', 'T_KCD']
           }
 
 time_columns = ['ДЛИТ_ПЕЧЬ']
@@ -109,7 +110,7 @@ groups = [
           'T_KCU',
           'T_KCV',
           'T_KCD',
-          'T_KCDV'
+        #   'T_KCDV'
 ]
 
 predictors = [
@@ -156,7 +157,7 @@ predictors = [
           'T_KCU',
           'T_KCV',
           'T_KCD',
-          'T_KCDV'
+        #   'T_KCDV'
 ]
 
 group_starts_with = {
@@ -169,4 +170,15 @@ group_starts_with = {
         'Group_КВР_УСП_01': ['КВР_УСП_01','КВР_УСП_02','КВР_УСП_03','КВР_УСП_04','КВР_УСП_05','КВР_УСП_06','КВР_УСП_07','КВР_УСП_08','КВР_УСП_09','КВР_УСП_10','КВР_УСП_11','КВР_УСП_12','КВР_УСП_13','КВР_УСП_14','КВР_УСП_15',],  # 8
         'Group_КВР_СКР_01': ['КВР_СКР_01','КВР_СКР_02','КВР_СКР_03','КВР_СКР_04','КВР_СКР_05','КВР_СКР_06','КВР_СКР_07','КВР_СКР_08','КВР_СКР_09','КВР_СКР_10','КВР_СКР_11','КВР_СКР_12','КВР_СКР_13','КВР_СКР_14','КВР_СКР_15'],  # 9
         'Group_DELTA1_2': ['DELTA1_2','DELTA2_3','DELTA3_4','DELTA4_5','DELTA5_6','DELTA6_7','DELTA7_8','DELTA8_9','DELTA9_10','DELTA10_11','DELTA11_12','DELTA12_13','DELTA13_14','DELTA14_15'],  # 5
-}
\ No newline at end of file
+}
+
+item_to_group = {
+        'ДУО_ОБЖ_01': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_02': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_03': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_04': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_05': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_06': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_07': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_08': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_09': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_10': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_11': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_12': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_13': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_14': 'Group_ДУО_ОБЖ_01', 'ДУО_ОБЖ_15': 'Group_ДУО_ОБЖ_01',
+        'ДУО_УСС_01': 'Group_ДУО_УСС_01', 'ДУО_УСС_02': 'Group_ДУО_УСС_01', 'ДУО_УСС_03': 'Group_ДУО_УСС_01', 'ДУО_УСС_04': 'Group_ДУО_УСС_01', 'ДУО_УСС_05': 'Group_ДУО_УСС_01', 'ДУО_УСС_06': 'Group_ДУО_УСС_01', 'ДУО_УСС_07': 'Group_ДУО_УСС_01', 'ДУО_УСС_08': 'Group_ДУО_УСС_01', 'ДУО_УСС_09': 'Group_ДУО_УСС_01', 'ДУО_УСС_10': 'Group_ДУО_УСС_01', 'ДУО_УСС_11': 'Group_ДУО_УСС_01', 'ДУО_УСС_12': 'Group_ДУО_УСС_01', 'ДУО_УСС_13': 'Group_ДУО_УСС_01', 'ДУО_УСС_14': 'Group_ДУО_УСС_01', 'ДУО_УСС_15': 'Group_ДУО_УСС_01',
+        'ДУО_УСП_01': 'Group_ДУО_УСП_01', 'ДУО_УСП_02': 'Group_ДУО_УСП_01', 'ДУО_УСП_03': 'Group_ДУО_УСП_01', 'ДУО_УСП_04': 'Group_ДУО_УСП_01', 'ДУО_УСП_05': 'Group_ДУО_УСП_01', 'ДУО_УСП_06': 'Group_ДУО_УСП_01', 'ДУО_УСП_07': 'Group_ДУО_УСП_01', 'ДУО_УСП_08': 'Group_ДУО_УСП_01', 'ДУО_УСП_09': 'Group_ДУО_УСП_01', 'ДУО_УСП_10': 'Group_ДУО_УСП_01', 'ДУО_УСП_11': 'Group_ДУО_УСП_01', 'ДУО_УСП_12': 'Group_ДУО_УСП_01', 'ДУО_УСП_13': 'Group_ДУО_УСП_01', 'ДУО_УСП_14': 'Group_ДУО_УСП_01', 'ДУО_УСП_15': 'Group_ДУО_УСП_01',
+        'ДУО_СКР_01': 'Group_ДУО_СКР_01', 'ДУО_СКР_02': 'Group_ДУО_СКР_01', 'ДУО_СКР_03': 'Group_ДУО_СКР_01', 'ДУО_СКР_04': 'Group_ДУО_СКР_01', 'ДУО_СКР_05': 'Group_ДУО_СКР_01', 'ДУО_СКР_06': 'Group_ДУО_СКР_01', 'ДУО_СКР_07': 'Group_ДУО_СКР_01', 'ДУО_СКР_08': 'Group_ДУО_СКР_01', 'ДУО_СКР_09': 'Group_ДУО_СКР_01', 'ДУО_СКР_10': 'Group_ДУО_СКР_01', 'ДУО_СКР_11': 'Group_ДУО_СКР_01', 'ДУО_СКР_12': 'Group_ДУО_СКР_01', 'ДУО_СКР_13': 'Group_ДУО_СКР_01', 'ДУО_СКР_14': 'Group_ДУО_СКР_01', 'ДУО_СКР_15': 'Group_ДУО_СКР_01',
+        'КВР_ОБЖ_01': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_02': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_03': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_04': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_05': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_06': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_07': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_08': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_09': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_10': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_11': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_12': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_13': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_14': 'Group_КВР_ОБЖ_01', 'КВР_ОБЖ_15': 'Group_КВР_ОБЖ_01',
+        'КВР_УСС_01': 'Group_КВР_УСС_01', 'КВР_УСС_02': 'Group_КВР_УСС_01', 'КВР_УСС_03': 'Group_КВР_УСС_01', 'КВР_УСС_04': 'Group_КВР_УСС_01', 'КВР_УСС_05': 'Group_КВР_УСС_01', 'КВР_УСС_06': 'Group_КВР_УСС_01', 'КВР_УСС_07': 'Group_КВР_УСС_01', 'КВР_УСС_08': 'Group_КВР_УСС_01', 'КВР_УСС_09': 'Group_КВР_УСС_01', 'КВР_УСС_10': 'Group_КВР_УСС_01', 'КВР_УСС_11': 'Group_КВР_УСС_01', 'КВР_УСС_12': 'Group_КВР_УСС_01', 'КВР_УСС_13': 'Group_КВР_УСС_01', 'КВР_УСС_14': 'Group_КВР_УСС_01', 'КВР_УСС_15': 'Group_КВР_УСС_01',
+        'КВР_УСП_01': 'Group_КВР_УСП_01', 'КВР_УСП_02': 'Group_КВР_УСП_01', 'КВР_УСП_03': 'Group_КВР_УСП_01', 'КВР_УСП_04': 'Group_КВР_УСП_01', 'КВР_УСП_05': 'Group_КВР_УСП_01', 'КВР_УСП_06': 'Group_КВР_УСП_01', 'КВР_УСП_07': 'Group_КВР_УСП_01', 'КВР_УСП_08': 'Group_КВР_УСП_01', 'КВР_УСП_09': 'Group_КВР_УСП_01', 'КВР_УСП_10': 'Group_КВР_УСП_01', 'КВР_УСП_11': 'Group_КВР_УСП_01', 'КВР_УСП_12': 'Group_КВР_УСП_01', 'КВР_УСП_13': 'Group_КВР_УСП_01', 'КВР_УСП_14': 'Group_КВР_УСП_01', 'КВР_УСП_15': 'Group_КВР_УСП_01',
+        'КВР_СКР_01': 'Group_КВР_СКР_01', 'КВР_СКР_02': 'Group_КВР_СКР_01', 'КВР_СКР_03': 'Group_КВР_СКР_01', 'КВР_СКР_04': 'Group_КВР_СКР_01', 'КВР_СКР_05': 'Group_КВР_СКР_01', 'КВР_СКР_06': 'Group_КВР_СКР_01', 'КВР_СКР_07': 'Group_КВР_СКР_01', 'КВР_СКР_08': 'Group_КВР_СКР_01', 'КВР_СКР_09': 'Group_КВР_СКР_01', 'КВР_СКР_10': 'Group_КВР_СКР_01', 'КВР_СКР_11': 'Group_КВР_СКР_01', 'КВР_СКР_12': 'Group_КВР_СКР_01', 'КВР_СКР_13': 'Group_КВР_СКР_01', 'КВР_СКР_14': 'Group_КВР_СКР_01', 'КВР_СКР_15': 'Group_КВР_СКР_01',
+        'DELTA1_2': 'Group_DELTA1_2', 'DELTA2_3': 'Group_DELTA1_2', 'DELTA3_4': 'Group_DELTA1_2', 'DELTA4_5': 'Group_DELTA1_2', 'DELTA5_6': 'Group_DELTA1_2', 'DELTA6_7': 'Group_DELTA1_2', 'DELTA7_8': 'Group_DELTA1_2', 'DELTA8_9': 'Group_DELTA1_2', 'DELTA9_10': 'Group_DELTA1_2', 'DELTA10_11': 'Group_DELTA1_2', 'DELTA11_12': 'Group_DELTA1_2', 'DELTA12_13': 'Group_DELTA1_2', 'DELTA13_14': 'Group_DELTA1_2', 'DELTA14_15': 'Group_DELTA1_2'}
\ No newline at end of file
