@@ -138,7 +138,7 @@ class DB_Connector:
         # ex: ['FPT', 'FUV_1'] -> ['FPT', 'FUV']
         else:
             target_columns = [columns2targets[i] for i in target_columns]
-            target_columns = flatten(target_columns)
+            target_columns = list(set(flatten(target_columns)))
 
         return target_columns, feature_columns
 
